"""
SPDX-License-Identifier: GPL-3.0-or-later
Copyright (c) 2013-2024 XVM Contributors
"""

# This Python file uses the following encoding: utf-8

from xfw import *
from logger import *


# PUBLIC

def getShortName(key, level, vclass):
    if IS_DEVELOPMENT:
        global _data
        if key not in _data:
            log('Warning: no short vehicle name for "{}" level={} class={}'.format(key, level, vclass))
    return _data.get(key, None)


def checkNames(vehs):
    if IS_DEVELOPMENT:
        global _data
        for key in _data:
            if not any(x['key'] == key for x in vehs):
                log('Warning: short name for non-existent vehicle "{}"'.format(key))


# PRIVATE

_data = {
    # Last update WG: 10.05.2023
    "china:Ch00_ClingeBot_SH":                           'CB·ch',
    "china:Ch01_Type59":                                 'Typ59',
    "china:Ch01_Type59_Gold":                            'Typ59g',
    "china:Ch02_Type62":                                 'Typ62',
    "china:Ch03_WZ-111":                                 '111',
    "china:Ch03_WZ_111_A":                               '111a',
    "china:Ch04_T34_1":                                  't34·1',
    "china:Ch05_T34_2":                                  't34·2',
    "china:Ch06_Renault_NC31":                           'NC31',
    # "china:Ch06_Renault_NC31_bot":                       'NC31',
    "china:Ch07_Vickers_MkE_Type_BT26":                  'TypB',
    "china:Ch08_Type97_Chi_Ha":                          'ChiHa',
    # "china:Ch08_Type97_Chi_Ha_bootcamp":                 'ChiHa',
    "china:Ch09_M5":                                     'ChM5',
    "china:Ch10_IS2":                                    'IS2',
    "china:Ch11_110":                                    '110',
    "china:Ch11_110_IGR":                                '110',
    "china:Ch12_111_1_2_3":                              '111·4',
    "china:Ch12_111_1_2_3_FL":                           '111·4·fl',
    "china:Ch14_T34_3":                                  't34·3',
    "china:Ch15_59_16":                                  '59·16',
    "china:Ch16_WZ_131":                                 'wz131',
    "china:Ch17_WZ131_1_WZ132":                          'wz132',
    "china:Ch17_WZ131_1_WZ132_IGR":                      'wz132',
    "china:Ch17_WZ131_1_WZ132_FL":                       'wz132',
    "china:Ch18_WZ-120":                                 'wz120',
    "china:Ch19_121":                                    '121',
    "china:Ch19_121_IGR":                                '121',
    "china:Ch20_Type58":                                 'Typ58',
    # "china:Ch20_Type58_bootcamp":                        'Typ58',
    "china:Ch21_T34":                                    'tp·t34',
    "china:Ch22_113":                                    '113',
    "china:Ch22_113P":                                   '113',
    "china:Ch22_113_Beijing_Opera":                      '113·bo',
    "china:Ch23_112":                                    '112',
    "china:Ch23_112_FL":                                 '112·fl',
    "china:Ch24_Type64":                                 'Typ64',
    "china:Ch24_Type64_SH":                              'Typ64',
    "china:Ch25_121_mod_1971B":                          '121B',
    "china:Ch25_121_mod_1971B_MK":                       '121B·MK',
    "china:Ch26_59_Patton":                              '59Pat',
    "china:Ch28_WZ_132A":                                'wz132a',
    "china:Ch29_Type_62C_prot":                          'wz132·1',
    "china:Ch30_T-26G_FT":                               't26g·ft',
    "china:Ch31_M3G_FT":                                 'm3g·ft',
    "china:Ch32_SU-76G_FT":                              'su76g·ft',
    "china:Ch33_60G_FT":                                 '60g·ft',
    "china:Ch34_WZ131G_FT":                              '131g·ft',
    "china:Ch35_T-34-2G_FT":                             't34·2g·ft',
    "china:Ch36_WZ111_1G_FT":                            '111·1·ft',
    "china:Ch37_WZ111G_FT":                              '111g·ft',
    "china:Ch38_WZ113G_FT":                              '113g·ft',
    "china:Ch39_WZ120_1G_FT":                            '120·1ft',
    "china:Ch39_WZ120_1G_FT_FL":                         '120·1ft·fl',
    "china:Ch40_WZ120G_FT":                              '120G·ft',
    "china:Ch41_WZ_111_5A":                              '111·5a',
    "china:Ch41_WZ_111_5A_7x7":                          '111·5a',
    "china:Ch41_WZ_111_QL":                              '111·lq',
    "china:Ch41_WZ_111_MT":                              '111·mt',
    "china:Ch42_WalkerBulldog_M41D":                     'M41D',
    "china:Ch43_WZ_122_2":                               'wz122·2',
    "china:Ch44_114_SP2":                                '114·SP2',
    "china:Ch45_WZ_114":                                 'wz114',
    "china:Ch46_113_140":                                '113/140',
    "china:Ch47_BZ_176":                                 'bz.176',
    "china:Ch48_BZ_75":                                  'bz.75',
    "china:Ch49_BZ_68":                                  'bz.68',
    "china:Ch50_BZ_166":                                 'bz.166',
    "china:Ch51_BZ_58":                                  'bz.58',
    "china:Ch52_WZ_122_6_F3":                            'wz.122.6.f3',
    "china:Ch53_T_26_China":                             't26·C',
    "china:Ch58_111_Vz51":                               '111.wz51',
    "china:Ch59_BZ58_2":                                 'bz.58·2',
    "czech:Cz01_Skoda_T40":                              'skT40',
    "czech:Cz02_TVP_T50":                                'skT50',
    "czech:Cz03_LT_vz35":                                'vz.35',
    "czech:Cz04_T50_51":                                 'skT50·51',
    "czech:Cz05_T34_100":                                't34·100',
    "czech:Cz06_Kolohousenka":                           'khous',
    "czech:Cz07_TVP_46":                                 'vtu',
    "czech:Cz08_T_25":                                   'skT25',
    "czech:Cz09_T_24":                                   'skT24',
    "czech:Cz10_LT_vz38":                                'vz.38',
    "czech:Cz11_V_8_H":                                  'vz.39',
    "czech:Cz13_T_27":                                   'skT27',
    "czech:Cz14_Skoda_T-56":                             'skT56',
    "czech:Cz15_Skoda_T-45_Prem":                        'skT45',
    "czech:Cz16_TNH_T_vz51":                             'tnh·vz51',
    "czech:Cz17_Vz_55":                                  'vz55',
    "czech:Cz17_Vz_55_CN":                               'vz55·CN',
    "czech:Cz18_TNH_105_1000":                           'tnh·105',
    "czech:Cz19_Vz_44_1":                                'vz44·1',
    "czech:Cz20_ShPTK_TVP_100_mm":                       'ShPTK·100',
    "france:F01_RenaultFT":                              'FT',
    # "france:F01_RenaultFT_bot":                          'FT',
    "france:F02_D1":                                     'D1',
    "france:F03_D2":                                     'D2',
    "france:F04_B1":                                     'B1',
    # "france:F04_B1_bootcamp":                            'B1',
    "france:F05_BDR_G1B":                                'BDR',
    "france:F06_ARL_44":                                 'Arl44',
    "france:F07_AMX_M4_1945":                            'amx4·45',
    "france:F08_AMX_50_100":                             '50100',
    "france:F08_AMX_50_100_IGR":                         '50100',
    "france:F09_AMX_50_120":                             '50120',
    "france:F100_Panhard_EBR_90":                        'ebr90',
    "france:F1035_AMX_AC_Mle1946_bootcamp":              'amx·1946',
    "france:F106_Panhard_EBR_75_Mle1954":                'ebr75',
    "france:F107_Hotchkiss_EBR":                         'ebrHotch',
    "france:F108_Panhard_EBR_105":                       'ebr105',
    "france:F109_AMD_Panhard_178B":                      'amd178b',
    "france:F10_AMX_50B":                                '50B',
    "france:F10_AMX_50B_fallout":                        '50B',
    "france:F110_Lynx_6x6":                              'lynx6x6',
    "france:F111_AM39_Gendron_Somua":                    'am.Gedr',
    "france:F112_M10_RBFM":                              'M10.rbfm',
    "france:F113_Bretagne_Panther":                      'Bret.Pant',
    "france:F114_Projet_4_1":                            'Char.Fut.4',
    "france:F115_Lorraine_50t":                          'Lr50t',
    "france:F116_Bat_Chatillon_Bourrasque":              'Bourr.',
    "france:F117_Alt_Proto_AMX_30":                      'a.p·amx30',
    "france:F118_Char_Mle_75":                           'char·mle·75',
    "france:F11_Renault_G1R":                            'G1R',
    "france:F12_Hotchkiss_H35":                          'h35',
    "france:F13_AMX38":                                  'amx38',
    "france:F14_AMX40":                                  'amx40',
    "france:F15_AMX_12t":                                'amx12',
    "france:F16_AMX_13_75":                              '13·75',
    "france:F17_AMX_13_90":                              '13·90',
    "france:F17_AMX_13_90_IGR":                          '13·90',
    "france:F18_Bat_Chatillon25t":                       'BChat',
    "france:F18_Bat_Chatillon25t_IGR":                   'BChat',
    "france:F19_Lorraine40t":                            'Lr40t',
    "france:F20_RenaultBS":                              'ftBS',
    "france:F21_Lorraine39_L_AM":                        '39Lam',
    "france:F22_AMX_105AM":                              '13AM',
    "france:F23_AMX_13F3AM":                             '13F3',
    "france:F23_AMX_13F3AM_MapsTraining_Dummy_SPG_2":    '13F3',
    "france:F24_Lorraine155_50":                         '155·50',
    "france:F25_Lorraine155_51":                         '155·51',
    "france:F27_FCM_36Pak40":                            'Pak40',
    "france:F28_105_leFH18B2":                           'leFH',
    "france:F28_105_leFH18B2_IGR":                       'leFH',
    "france:F30_RenaultFT_AC":                           'ftAC',
    "france:F32_Somua_Sau_40":                           'SAu40',
    "france:F33_S_35CA":                                 'S35ca',
    "france:F33_S_35CA_IGR":                             'S35ca',
    "france:F34_ARL_V39":                                'Arl39',
    "france:F35_AMX_AC_Mle1946":                         'amx46',
    "france:F36_AMX_AC_Mle1948":                         'amx48',
    "france:F36_AMX_AC_Mle1948_IGR":                     'amx48',
    "france:F36_AMX_AC_Mle1948_FL":                      'amx48',
    "france:F37_AMX50_Foch":                             'Foch',
    "france:F38_Bat_Chatillon155_58":                    '155·58',
    "france:F42_AMR_35":                                 'amr35',
    "france:F43_AMC_35_SH":                              'arlec.',
    "france:F44_Somua_S35":                              'SomS35',
    "france:F49_RenaultR35":                             'R35',
    "france:F50_FCM36_20t":                              'fcm36',
    "france:F52_RenaultUE57":                            'UE57',
    "france:F62_ELC_AMX":                                'ELC',
    "france:F62_ELC_AMX_IGR":                            'ELC',
    "france:F64_AMX_50Fosh_155":                         'Fch155',
    "france:F64_AMX_50Fosh_B":                           'Fch·B',
    "france:F65_FCM_50t":                                'fcm50t',
    "france:F66_AMX_Ob_Am105":                           '105AM',
    "france:F67_Bat_Chatillon155_55":                    '155·55',
    "france:F68_AMX_Chasseur_de_char_46":                'CDC',
    "france:F69_AMX13_57_100":                           '13·57',
    "france:F69_AMX13_57_100_GrandFinal":                '13·57·GF',
    "france:F70_SARL42":                                 'sarl42',
    "france:F71_AMX_30_prototype":                       'amx30',
    "france:F72_AMX_30":                                 'amx30b',
    "france:F73_M4A1_Revalorise":                        'm4a1',
    "france:F73_M4A1_Revalorise_FL":                     'm4a1·fl',
    "france:F74_AMX_M4_1949":                            'amx4·49',
    "france:F74_AMX_M4_1949_FL":                         'amx4·49·fl',
    "france:F74_AMX_M4_1949_Liberte":                    'amx4·49',
    "france:F75_Char_de_25t":                            'BChatAP',
    "france:F81_Char_de_65t":                            'amx65t',
    "france:F82_AMX_M4_Mle1949_Ter":                     'amx4·54',
    "france:F83_AMX_M4_Mle1949_Bis":                     'amx4·51',
    "france:F83_AMX_M4_Mle1949_Bis_FL":                  'amx4·51·fl',
    "france:F84_Somua_SM":                               'Som·SM',
    "france:F85_M4A1_FL10":                              'm4a1·fl10',
    "france:F87_Batignolles-Chatillon_12t":              'BChat12t',
    "france:F88_AMX_13_105":                             '13·105',
    "france:F88_AMX_13_105_7x7":                         '13·105',
    "france:F89_Canon_dassaut_de_105":                   'amx·cda',
    "france:F97_ELC_EVEN_90":                            'elcEv90',
    "france:F97_ELC_EVEN_90_FL":                         'elcEv90·fl',
    "germany:Env_Artillery":                             'E.Art',
    "germany:G00_Bomber_SH":                             'brander',
    "germany:G02_Hummel":                                'Humml',
    "germany:G03_PzV_Panther":                           'Pant',
    "germany:G03_PzV_Panther_IGR":                       'Pant',
    # "germany:G03_PzV_Panther_bootcamp":                  'Pant',
    "germany:G04_PzVI_Tiger_I":                          'Tig1',
    "germany:G04_PzVI_Tiger_I_MapsTraining_Player_HT_2": 'Tig1',
    "germany:G04_PzVI_Tiger_IA":                         'Tig1a',
    "germany:G04_PzVI_Tiger_I_IGR":                      'Tig1',
    "germany:G05_StuG_40_AusfG":                         'StugG',
    "germany:G05_StuG_40_AusfG_IGR":                     'StugG',
    "germany:G06_PzII":                                  'Pz2',
    # "germany:G06_PzII_bot":                              'Pz2',
    "germany:G07_Pz35t":                                 'Pz35t',
    "germany:G08_Pz38t":                                 'Pz38t',
    # "germany:G08_Pz38t_bootcamp":                        'Pz38t',
    "germany:G09_Hetzer":                                'Hetzr',
    "germany:G09_Hetzer_MapsTraining_Dummy_ATSPG_1":     'Hetzr',
    "germany:G100_Gtraktor_Krupp":                       'GrTr',
    "germany:G101_StuG_III":                             'StugB',
    "germany:G102_Pz_III":                               'Pz3e',
    # "germany:G102_Pz_III_bootcamp":                      'Pz3e',
    "germany:G103_RU_251":                               'Ru251',
    "germany:G104_Stug_IV":                              'Stug4',
    "germany:G105_T-55_NVA_DDR":                         'T·55a',
    "germany:G106_PzKpfwPanther_AusfF":                  'Pant88',
    "germany:G107_PzKpfwIII_AusfK":                      'Pz3k',
    "germany:G108_PzKpfwII_AusfD":                       'Pz2d',
    "germany:G109_Steyr_WT":                             'WTstr',
    "germany:G10_PzIII_AusfJ":                           'Pz3',
    "germany:G110_Typ_205":                              'Mausch',
    "germany:G112_KanonenJagdPanzer":                    'KnJpz',
    "germany:G112_KanonenJagdPanzer_105":                'KnJpz',
    "germany:G113_SP_I_C":                               'sp1c',
    "germany:G114_Rheinmetall_Skorpian":                 'skorp',
    "germany:G114_Skorpian":                             'skorp',
    "germany:G115_Typ_205B":                             '100.01p',
    "germany:G115_Typ_205_4_Jun":                        'vk100',
    "germany:G116_Turan_III_prot":                       'Turn3',
    "germany:G117_Toldi_III":                            'Told3',
    # "germany:G117_Toldi_III_bootcamp":                   'Told3',
    "germany:G118_VK4503":                               '4503',
    "germany:G119_Panzer58":                             'Pz58',
    "germany:G119_Panzer58_BF":                          'Pz58bf',
    "germany:G119_Panzer58_FL":                          'Pz58·fl',
    "germany:G119_Pz58_Mutz":                            'mutz',
    "germany:G11_Bison_I":                               'Bison',
    "germany:G120_M41_90":                               'M41·90',
    "germany:G120_M41_90_GrandFinal":                    'M41·90·GF',
    "germany:G121_Grille_15_L63":                        'Grill15',
    "germany:G122_VK6501H":                              '6501h',
    "germany:G125_Spz_57_Rh":                            'Rhm.Pzw',
    "germany:G126_HWK_12":                               'HWK12',
    "germany:G12_Ltraktor":                              'Ltr',
    # "germany:G12_Ltraktor_bot":                          'Ltr',
    "germany:G134_PzKpfw_VII":                           'PzKf·VII',
    "germany:G136_Tiger_131":                            'Tig131',
    "germany:G137_PzVI_Tiger_217":                       'Tig217',
    "germany:G138_VK168_02":                             '168.01p',
    "germany:G138_VK168_02_Mauerbrecher":                'MaurBrec',
    "germany:G139_MKA":                                  'MKA',
    "germany:G13_VK3001H":                               '3001h',
    "germany:G140_HWK_30":                               'HWK30',
    "germany:G141_VK7501K":                              '7501k',
    "germany:G142_M48RPz":                               '7501k',
    "germany:G143_E75_TS":                               '7501k',
    "germany:G144_Kpz_50t":                              'Kpz50t',
    "germany:G147_Kunze_Panzer":                         'Kunze.Pz',
    "germany:G151_Pz_Sfl_IC":                            'pz.Sfl.IC',
    "germany:G154_Kpz_07_RH":                            'kpz.07.RH',
    "germany:G158_VK2801_105_SPXXI":                     '2801·105',
    "germany:G159_KPZ_3_Project_07_HK":                  'kpz3.07.HK',
    "germany:G15_VK3601H":                               '3601h',
    "germany:G160_Pz_Kpfw_35_R_mit_T_26_Turm":           'Pz35R',
    "germany:G161_Pz_Kpfw_M15_38_t":                     'PzM15',
    "germany:G163_Pz_Kpfw_KW_Ir_mit_75mm_kwk40":         'pz.75.40',
    "germany:G166_LKpz_70_K":                            'LKpz.70.K',
    "germany:G16_PzVIB_Tiger_II":                        'Tig2',
    "germany:G16_PzVIB_Tiger_II_F":                      'Tig2·h',
    "germany:G16_PzVIB_Tiger_II_IGR":                    'Tig2',
    "germany:G16_PzVIB_Tiger_II_FL":                     'Tig2·fl',
    "germany:G17_JagdPzIV":                              'Jpz4',
    "germany:G18_JagdPanther":                           'JagPnt',
    "germany:G19_Wespe":                                 'Wespe',
    "germany:G20_Marder_II":                             'Mrdr2',
    "germany:G21_PanzerJager_I":                         'PzJg1',
    # "germany:G21_PanzerJager_I_bootcamp":                'PzJg1',
    "germany:G22_Sturmpanzer_II":                        'StPz2',
    "germany:G23_Grille":                                'Grill',
    "germany:G24_VK3002DB":                              '3002d',
    "germany:G24_VK3002DB_SH":                           'walkur.',
    "germany:G25_PzII_Luchs":                            'Luchs',
    "germany:G26_VK1602":                                'Leo',
    "germany:G27_VK3001P":                               '3001p',
    "germany:G28_PzIII_IV":                              'Pz3·4',
    "germany:G32_PzV_PzIV":                              'Pz5·4',
    "germany:G32_PzV_PzIV_CN":                           'Pz5·BP',
    "germany:G32_PzV_PzIV_ausf_Alfa":                    'Pz5·4a',
    "germany:G32_PzV_PzIV_ausf_Alfa_CN":                 'Pz5·BPa',
    "germany:G33_H39_captured":                          'Pz38h',
    "germany:G34_S35_captured":                          'PzS35',
    "germany:G35_B-1bis_captured":                       'PzB2',
    "germany:G36_PzII_J":                                'Pz2j',
    "germany:G37_Ferdinand":                             'Ferd',
    "germany:G37_Ferdinand_FL":                          'Ferd·fl',
    "germany:G37_Ferdinand_IGR":                         'Ferd',
    "germany:G39_Marder_III":                            'Mrdr38',
    "germany:G40_Nashorn":                               'Nash',
    "germany:G40_Nashorn_MapsTraining_Dummy_ATSPG_2":    'Nash',
    "germany:G41_DickerMax":                             'DMax',
    "germany:G42_Maus":                                  'Maus',
    "germany:G42_Maus_IGR":                              'Maus',
    "germany:G43_Sturer_Emil":                           'Emil',
    "germany:G44_JagdTiger":                             'JagT',
    "germany:G44_JagdTigerH":                            'JagT·h',
    "germany:G44_JagdTiger_FL":                          'JagT·fl',
    "germany:G45_G_Tiger":                               'GWT',
    "germany:G46_T-25":                                  'T·25',
    "germany:G48_E-25":                                  'E·25',
    "germany:G48_E-25_IGR":                              'E·25',
    "germany:G49_G_Panther":                             'GWP',
    "germany:G50_T-15":                                  'T·15',
    "germany:G51_Lowe":                                  'Lowe',
    "germany:G51_Lowe_FL":                               'Lowe·fl',
    "germany:G52_Pz38_NA":                               'Pz38na',
    "germany:G53_PzI":                                   'Pz1',
    "germany:G54_E-50":                                  'E·50',
    "germany:G54_E-50_FL":                               'E·50·fl',
    "germany:G55_E-75":                                  'E·75',
    "germany:G56_E-100":                                 'E·100',
    "germany:G57_PzVI_Tiger_P":                          'TigP',
    "germany:G58_VK4502P":                               '4502b',
    "germany:G58_VK4502P7":                              '4502b7',
    "germany:G61_G_E":                                   'GWE',
    "germany:G63_PzI_ausf_C":                            'Pz1c',
    "germany:G64_Panther_II":                            'Pant2',
    "germany:G64_Panther_II_IGR":                        'Pant2',
    "germany:G65_JagdTiger_SdKfz_185":                   'JgT88',
    "germany:G65_JagdTiger_SdKfz_185_IGR":               'JgT88',
    "germany:G66_VK2801":                                'vk2801',
    "germany:G67_VK4502A":                               '4502a',
    "germany:G70_PzIV_Hydro":                            'Pz4hy',
    "germany:G71_JagdPantherII":                         'JagP2',
    "germany:G72_JagdPz_E100":                           'Jpz100',
    "germany:G73_E50_Ausf_M":                            'E·50m',
    "germany:G73_E50_Ausf_M_7x7":                        'E·50m',
    "germany:G76_Pz_Sfl_IVc":                            'PzS4c',
    "germany:G77_PzIV_Schmalturm":                       'Pz4s',
    "germany:G78_Panther_M10":                           'PanM10',
    "germany:G79_Pz_IV_AusfGH":                          'Pz4',
    "germany:G80_Pz_IV_AusfD":                           'Pz4d',
    "germany:G80_Pz_IV_AusfD_bootcamp":                  'Pz4d',
    "germany:G81_Pz_IV_AusfH":                           'Pz4h',
    "germany:G81_Pz_IV_AusfH_GuP":                       'Pz4h·ank',
    "germany:G82_Pz_II_AusfG":                           'Pz2g',
    "germany:G83_Pz_IV_AusfA":                           'Pz4a',
    "germany:G85_Auf_Panther":                           'AufPan',
    "germany:G85_Aufklarungspanzer_V":                   'AufPz5',
    "germany:G86_VK2001DB":                              'vk2001',
    "germany:G87_VK3002DB_V1":                           '3001d',
    "germany:G88_Indien_Panzer":                         'IndPz',
    "germany:G89_Leopard1":                              'Leo1',
    "germany:G89_Leopard1_bob":                          'Leo1·bb',
    "germany:G90_DW_II":                                 'DW2',
    "germany:G90_DW_II_MapsTraining_Dummy_HT_1":         'DW2',
    "germany:G91_Pro_Ag_A":                              'LeoPrA',
    "germany:G92_VK7201":                                'vk7201',
    "germany:G93_GW_Mk_VIe":                             'Gpz·VI',
    "germany:G94_GW_Tiger_P":                            'GWTP',
    "germany:G95_Pz_Sfl_IVb":                            'PzS4b',
    "germany:G96_VK3002M":                               '3002m',
    "germany:G97_Waffentrager_IV":                       'WT4',
    "germany:G98_Waffentrager_E100":                     'WT100',
    "germany:G98_Waffentrager_E100_P":                   'WT100p',
    "germany:G98_Waffentrager_E100_WO":                  'WT100wo',
    "germany:G99_RhB_Waffentrager":                      'WTRhB',
    "italy:It03_M15_42":                                 'M15/42',
    "italy:It04_Fiat_3000":                              'Fiat3000',
    "italy:It05_Carro_L6_40":                            'L6/40',
    "italy:It06_M14_41":                                 'M14/41',
    "italy:It07_P26_40":                                 'M26/40',
    "italy:It08_Progetto_M40_mod_65":                    'Prog65',
    "italy:It08_Progetto_M40_mod_65_bob":                'Prog65·bb',
    "italy:It09_P43_ter":                                'P43·ter',
    "italy:It10_P43_bis":                                'P43·bis',
    "italy:It11_P43":                                    'P43',
    "italy:It12_Prototipo_Standard_B":                   'Stand·B',
    "italy:It13_Progetto_M35_mod_46":                    'Prog46',
    "italy:It13_Progetto_M35_mod_46_LE":                 'Prog46·LE',
    "italy:It14_P44_Pantera":                            'P44·Pant',
    "italy:It15_Rinoceronte":                            'Rinocer.',
    "italy:It16_Carro_d_assalto_P88":                    'Carro.P88',
    "italy:It17_Progetto_CC55_mod_54":                   'Prog54',
    "italy:It18_Progetto_C45_mod_71":                    'Prog71',
    "italy:It19_Progetto_C50_mod_66":                    'Prog66',
    "italy:It20_Carro_Combattimento_45t":                'Carro45t',
    "italy:It21_Lion":                                   'Lion',
    "italy:It23_CC_3":                                   'CC·3',
    "italy:It24_Controcarro_1_Mk2":                      'Contro',
    "italy:It26_CC_56":                                  'CC·56',
    "italy:It27_M43_da_105_25_Bassoto":                  'Bassoto',
    "italy:It28_Semovente_M41_Da_75_18":                 'Semov',
    "italy:It29_Carro_Celere_Sahariano":                 'Sahariano',
    "italy:It30_CC_mod_64_Prem":                         'CC64·prem',
    "italy:It31_CC_67_B":                                'CC·67·B',
    "japan:J01_NC27":                                    'R.Ots',
    # "japan:J01_NC27_bot":                                'R.Ots',
    "japan:J02_Te_Ke":                                   'TeKe',
    "japan:J03_Ha_Go":                                   'HaGo',
    "japan:J04_Ke_Ni":                                   'KeNi',
    # "japan:J04_Ke_Ni_bootcamp":                          'KeNi',
    "japan:J05_Ke_Ni_B":                                 'KeNiO',
    "japan:J06_Ke_Ho":                                   'KeHo',
    "japan:J07_Chi_Ha":                                  'JChiHa',
    "japan:J08_Chi_Nu":                                  'ChiNu',
    "japan:J09_Chi_He":                                  'ChiHe',
    "japan:J10_Chi_To":                                  'ChiTo',
    "japan:J11_Chi_Ri":                                  'ChiRi',
    "japan:J11_Chi_Ri_IGR":                              'ChiRi',
    "japan:J12_Chi_Nu_Kai":                              'ChiNuK',
    "japan:J13_STA_1":                                   'sta·1',
    "japan:J13_STA_1_IGR":                               'sta·1',
    "japan:J14_Type_61":                                 'Typ61',
    "japan:J15_Chi_Ni":                                  'ChiNi',
    "japan:J16_ST_B1":                                   'stb·1',
    "japan:J16_ST_B1_IGR":                               'stb·1',
    "japan:J18_STA_2_3":                                 'sta·2',
    "japan:J19_Tiger_I_Jpn":                             'JapTig',
    "japan:J20_Type_2605":                               'Typ5',
    "japan:J21_Type_91":                                 'Typ91',
    "japan:J22_Type_95":                                 'Typ95',
    # "japan:J22_Type_95_bootcamp":                        'Typ95',
    "japan:J23_Mi_To":                                   'O·Iex',
    "japan:J24_Mi_To_130_tons":                          'O·I',
    "japan:J25_Type_4":                                  'Typ4',
    "japan:J26_Type_89":                                 'I·go',
    "japan:J27_O_I_120":                                 'O·ho',
    "japan:J27_O_I_120_BP":                              'O·ho',
    "japan:J28_O_I_100":                                 'O·ni',
    "japan:J29_Nameless":                                'Namel',
    "japan:J30_Edelweiss":                               'Edelw',
    # "japan:J31_Ho_To":                                   'ho·to',
    "japan:J31_Type_5_KaRi":                             'KaRi',
    "japan:J32_Chi_To_SPG":                              'ChiTo',
    "japan:J33_Ho_Ri_2":                                 'HoRi·2',
    "japan:J34_Ho_Ri_1":                                 'HoRi·1',
    "japan:J35_Ho_Ri_3":                                 'HoRi·3',
    "japan:J37_Type_3_Ho_Ni_III":                        'HoNi',
    "japan:J38_Type_95_Ji_Ro":                           'JiRo',
    "poland:Pl01_TKS_20mm":                              'tks20',
    "poland:Pl03_PzV_Poland":                            'Pudel',
    "poland:Pl05_50TP_Tyszkiewicza":                     '50TP',
    "poland:Pl06_10TP":                                  '10TP',
    "poland:Pl07_14TP":                                  '14TP',
    "poland:Pl08_50TP_prototyp":                         '50TP·pr',
    "poland:Pl09_7TP":                                   '7TP',
    "poland:Pl10_40TP_Habicha":                          '40TP',
    "poland:Pl11_45TP_Habicha":                          '45TP',
    "poland:Pl12_25TP_KSUST_II":                         '25TP',
    "poland:Pl13_53TP_Markowskiego":                     '53TP',
    "poland:Pl14_4TP":                                   '4TP',
    "poland:Pl15_60TP_Lewandowskiego":                   '60TP',
    "poland:Pl16_T34_85_Rudy":                           'Rudy',
    "poland:Pl17_DS_PZlnz":                              'ds·PZl.',
    "poland:Pl17_DS_PZlnz_SH":                           'ds·PZl.',
    "poland:Pl18_BUGI":                                  'bugi',
    "poland:Pl19_CS_52_LIS":                             'cs·52',
    "poland:Pl20_CS_44":                                 'cs·44',
    "poland:Pl21_CS_63":                                 'cs·63',
    "poland:Pl22_CS_59":                                 'cs·59',
    "poland:Pl23_CS_53":                                 'cs·53',
    "poland:Pl24_56TP":                                  '56TP',
    "poland:Pl25_CS_52_C":                               'cs·52',
    "sweden:S01_Strv_74_A2":                             'm42·57',
    "sweden:S02_Strv_M42":                               'm/42',
    "sweden:S03_Strv_M38":                               'm/38',
    "sweden:S04_Lago_I":                                 'lago',
    "sweden:S05_Strv_M21_29":                            'fm/21',
    "sweden:S06_Ikv_90_Typ_B_Bofors":                    'lkv90·b',
    "sweden:S07_Strv_74":                                'strv·74',
    "sweden:S08_Ikv_65_Alt_2":                           'lkv60·2',
    "sweden:S09_L_120_TD":                               'fm/42',
    "sweden:S10_Strv_103_0_Series":                      '103·0',
    "sweden:S10_Strv_103_0_Series_FL":                   '103·0·fl',
    "sweden:S11_Strv_103B":                              '103·b',
    "sweden:S12_Strv_M40":                               'm/40L',
    "sweden:S13_Leo":                                    'leo',
    "sweden:S14_Ikv_103":                                'lkv103',
    "sweden:S14_Ikv_103_SH":                             'lkv103',
    "sweden:S15_L_60":                                   'L60',
    "sweden:S16_Kranvagn":                               'kranv',
    "sweden:S16_Kranvagn_bob":                           'kranv·bb',
    "sweden:S17_EMIL_1952_E2":                           'emil·II',
    "sweden:S18_EMIL_1951_E1":                           'emil·I',
    "sweden:S19_Sav_M43":                                'm/43',
    "sweden:S20_Ikv_72":                                 'lkv72',
    "sweden:S21_UDES_03":                                'udes·03',
    "sweden:S22_Strv_S1":                                'strv·S1',
    "sweden:S22_Strv_S1_FL":                             'strv·S1·fl',
    "sweden:S23_Strv_81":                                'strv·81',
    "sweden:S23_Strv_81_sabaton":                        'Pr.Vict',
    "sweden:S25_EMIL_51":                                'emil·1951',
    "sweden:S26_Lansen_C":                               'lans·C',
    "sweden:S27_UDES_16":                                'udes·16',
    "sweden:S28_UDES_15_16":                             'udes·15/16',
    "sweden:S29_UDES_14_5":                              'udes·14·5',
    "sweden:S30_UDES_03_Alt_3":                          'udes·03·3',
    "sweden:S31_Strv_K":                                 'strv·K',
    "sweden:S32_Bofors_Tornvagn":                        'Tornvagn',
    "sweden:S33_Latta_Stridsfordon":                     'Strids',
    "sweden:S33_Latt_Stridsfordon_120":                  'Strids·120',
    "sweden:S34_Lago_M38":                               'lago.M38',
    "uk:GB01_Medium_Mark_I":                             'Med1',
    # "uk:GB01_Medium_Mark_I_bot":                         'Med1',
    "uk:GB03_Cruiser_Mk_I":                              'Crus1',
    "uk:GB04_Valentine":                                 'Valnt',
    "uk:GB05_Vickers_Medium_Mk_II":                      'Med2',
  # "uk:GB05_Vickers_Medium_Mk_II_bot":                  'Med2',
    "uk:GB06_Vickers_Medium_Mk_III":                     'Med3',
    "uk:GB07_Matilda":                                   'Matil',
    "uk:GB08_Churchill_I":                               'Chrch1',
    "uk:GB08_Churchill_I_IGR":                           'Chrch1',
    "uk:GB09_Churchill_VII":                             'Chrch7',
    "uk:GB100_Manticore":                                'Mantic',
    "uk:GB1019_Sherman_Firefly_NewOnBoarding":           'Firefly',
    "uk:GB101_FV1066_Senlac":                            'Senlac',
    "uk:GB1020_Crusader_NewOnBoarding":                  'Crusader',
    "uk:GB102_LHMTV":                                    'LHMTV',
    "uk:GB103_GSOR3301_AVR_FS":                          'GSOR',
    "uk:GB104_GSR_3301_Setter":                          'Setter',
    "uk:GB105_Black_Prince_2019":                        'A43bp',
    "uk:GB106_Cobra":                                    'Cobra',
    "uk:GB107_Cavalier":                                 'Caval.',
    "uk:GB107_Cavalier_SH":                              'harb.',
    "uk:GB108_A46":                                      'A46',
    "uk:GB109_GSOR_1008":                                'GSOR',
    "uk:GB10_Black_Prince":                              'BlPrn',
    "uk:GB110_FV4201_Chieftain_Prototype":               'Fv4201.CP',
    "uk:GB111_Charlemagne":                              'Charlem.',
    "uk:GB112_Caliban":                                  'Caliban',
    "uk:GB113_Matilda_LVT":                              'Mat·LVT',
    "uk:GB115_Gonsalo":                                  'Gonsalo',
    "uk:GB116_Harry_Hopkins_I":                          'H·H·1',
    "uk:GB11_Caernarvon":                                'Caer',
    "uk:GB11_Caernarvon_IGR":                            'Caer',
    "uk:GB120_Concept_No_5":                             'Conc5',
    "uk:GB121_GSOR_1010_FB":                             '1010',
    "uk:GB122_Staghound_Mk_III":                         'Stagh.',
    "uk:GB123_GSOR_1006_v7":                             '1006/7',
    "uk:GB124_AEC_Armoured_Car":                         'AEC',
    "uk:GB125_Saladin":                                  'Saladin',
    "uk:GB126_FSV_Scheme_A":                             'FSV·A',
    "uk:GB127_A7E3":                                     'A7E3',
    "uk:GB12_Conqueror":                                 'Conq',
    "uk:GB12_Conqueror_FL":                              'Conq·fl',
    "uk:GB13_FV215b":                                    'Fv215',
    "uk:GB13_FV215b_IGR":                                'Fv215',
    "uk:GB14_M2":                                        'M2',
    "uk:GB15_Stuart_I":                                  'stu-1·4',
    "uk:GB17_Grant_I":                                   'Grant',
    "uk:GB19_Sherman_Firefly":                           'Firef',
    "uk:GB19_Sherman_Firefly_MapsTraining_Dummy_MT_2":   'Firef',
    "uk:GB20_Crusader":                                  'Crsdr',
    "uk:GB21_Cromwell":                                  'Cromw',
    "uk:GB21_Cromwell_IGR":                              'Cromw',
    "uk:GB22_Comet":                                     'Comet',
    "uk:GB23_Centurion":                                 'Cent',
    "uk:GB23_Centurion_IGR":                             'Cent',
    "uk:GB24_Centurion_Mk3":                             'Cent7',
    "uk:GB25_Loyd_Gun_Carriage":                         'LoydG',
    "uk:GB26_Birch_Gun":                                 'Birch',
    "uk:GB27_Sexton":                                    'Sext2',
    "uk:GB28_Bishop":                                    'Bish',
    "uk:GB29_Crusader_5inch":                            'CruSP',
    "uk:GB30_FV3805":                                    'fv3805',
    "uk:GB31_Conqueror_Gun":                             'ConqG',
    "uk:GB32_Tortoise":                                  'Tort',
    "uk:GB33_Sentinel_AC_I":                             'Sentw',
    "uk:GB35_Sentinel_AC_IV":                            'SentAC',
    "uk:GB37_Valliant":                                  'Vali.',
    "uk:GB39_Universal_CarrierQF2":                      'QF2',
    "uk:GB40_Gun_Carrier_Churchill":                     'ChrGC',
    "uk:GB41_Challenger":                                'Chall',
    "uk:GB42_Valentine_AT":                              'ValAT',
    "uk:GB44_Archer":                                    'Arch',
    "uk:GB45_Achilles_IIC":                              'Achil',
    "uk:GB48_FV215b_183":                                'Fv183',
    "uk:GB50_Sherman_III":                               'Sherm3',
    "uk:GB51_Excelsior":                                 'Excel',
    "uk:GB52_A45":                                       'fv201',
    "uk:GB57_Alecto":                                    'Alect',
    "uk:GB58_Cruiser_Mk_III":                            'Crus3',
    "uk:GB59_Cruiser_Mk_IV":                             'Crus4',
    "uk:GB60_Covenanter":                                'Coven',
    "uk:GB63_TOG_II":                                    'TOG2',
    "uk:GB68_Matilda_Black_Prince":                      'MatBP',
    "uk:GB69_Cruiser_Mk_II":                             'Crus3',
    "uk:GB70_FV4202_105":                                'fv4202',
    "uk:GB70_N_FV4202_105":                              'fv4202p',
    "uk:GB70_N_FV4202_105_FL":                           'fv4202p',
    "uk:GB71_AT_15A":                                    'AT15a',
    "uk:GB72_AT15":                                      'AT15',
    "uk:GB72_AT15_IGR":                                  'AT15',
    "uk:GB73_AT2":                                       'AT2',
    "uk:GB74_AT8":                                       'AT8',
    "uk:GB75_AT7":                                       'AT7',
    "uk:GB76_Mk_VIC":                                    'L.vic',
    "uk:GB77_FV304":                                     'fv304',
    "uk:GB77_FV304_IGR":                                 'fv304',
    "uk:GB78_Sexton_I":                                  'Sext1',
    "uk:GB79_FV206":                                     'fv207',
    "uk:GB80_Charioteer":                                'Chari',
    "uk:GB81_FV4004":                                    'Conw',
    "uk:GB83_FV4005":                                    'fv4005',
    "uk:GB84_Chieftain_Mk6":                             'Chief',
    "uk:GB85_Cromwell_Berlin":                           'cromwB',
    "uk:GB86_Centurion_Action_X":                        'CentAX',
    "uk:GB86_Centurion_Action_X_7x7":                    'CentAX',
    "uk:GB87_Chieftain_T95_turret":                      'Chief/T95',
    "uk:GB88_T95_Chieftain_turret":                      'T95/Chief',
    "uk:GB91_Super_Conqueror":                           'S.Conq',
    "uk:GB92_FV217":                                     'Badger',
    "uk:GB92_FV217_7x7":                                 'Badger',
    "uk:GB93_Caernarvon_AX":                             'CaerAX',
    "uk:GB94_Centurion_Mk5-1_RAAC":                      'Cent5/1',
    "uk:GB95_Ekins_Firefly_M4A4":                        'FirefVC',
    "uk:GB96_Excalibur":                                 'Excalib',
    "uk:GB97_Chimera":                                   'Chimera',
    "uk:GB98_T95_FV4201_Chieftain":                      'T95/4201',
    "uk:GB99_Turtle_Mk1":                                'Turtle',
    "unknown":                                           'unk',
    "usa:A01_T1_Cunningham":                             'T1',
    # "usa:A01_T1_Cunningham_bot":                         'T1',
    "usa:A02_M2_lt":                                     'M2lt',
    "usa:A03_M3_Stuart":                                 'M3stu',
    # "usa:A03_M3_Stuart_bootcamp":                        'M3stu',
    "usa:A04_M3_Grant":                                  'M3Lee',
    "usa:A05_M4_Sherman":                                'M4A1',
    "usa:A05_M4_Sherman_IGR":                            'M4A1',
    "usa:A06_M4A3E8_Sherman":                            'M4A3',
    "usa:A07_T20":                                       'T20',
    "usa:A08_T23":                                       'T23',
    "usa:A09_T1_hvy":                                    'T1hv',
    "usa:A1006_M4A3E8_Sherman_NewOnBoarding":            'M4A3E8',
    "usa:A100_T49":                                      'T49',
    "usa:A101_M56":                                      'Scorp',
    "usa:A102_T28_concept":                              'T28c',
    "usa:A103_T71E1":                                    'T71da',
    "usa:A103_T71E1_IGR":                                'T71da',
    "usa:A1041_M18_Hellcat_NewOnBoarding":               'Hellc',
    "usa:A104_M4A3E8A":                                  'Fury',
    "usa:A106_M48A2_120":                                '54E2',
    "usa:A107_T1_HMC":                                   'T1hmc',
    "usa:A108_T18_HMC":                                  'T18hmc',
    "usa:A109_T56_GMC":                                  'T56gmc',
    "usa:A10_M6":                                        'M6',
    "usa:A1118_M4_Thunderbolt_NewOnBoarding":            'Thund.bt',
    "usa:A111_T25_Pilot":                                'T25PN1',
    "usa:A112_T71E2":                                    'T71cm·P',
    "usa:A112_T71E2R":                                   'T71cm',
    "usa:A115_Chrysler_K":                               'ChrysK',
    "usa:A115_Chrysler_K_GF":                            'ChrysK',
    "usa:A116_XM551":                                    'Sheri',
    "usa:A117_T26E5":                                    'T26e5',
    "usa:A117_T26E5_FL":                                 'T26e5·fl',
    "usa:A117_T26E5_Patriot":                            'T26e5',
    "usa:A118_M4_Thunderbolt":                           'Thund.bt',
    "usa:A11_T29":                                       'T29',
    "usa:A11_T29_IGR":                                   'Т29',
    "usa:A120_M48A5":                                    'M48Pt',
    "usa:A120_M48A5_7x7":                                'M48A5',
    "usa:A120_M48A5_IGR":                                'M48Pt',
    "usa:A121_M26_Cologne":                              'Eagle7',
    "usa:A122_TS-5":                                     'TS-5',
    "usa:A123_T78":                                      'T78',
    "usa:A124_T54E2":                                    'T54E2',
    "usa:A125_AEP_1":                                    'AEPh·I',
    "usa:A126_PzVI_Tiger_II_capt":                       'K.TigrC',
    "usa:A127_TL_1_LPC":                                 'TL1.lpc',
    "usa:A128_concept_1b":                               'Conc.1b',
    "usa:A129_T6_medium":                                'T6med',
    "usa:A129_T6_medium_MapsTraining_Dummy_MT_1":        'T6med',
    "usa:A12_T32":                                       'T32',
    "usa:A12_T32_FL":                                    'T32',
    "usa:A12_T32_M":                                     'T32·M',
    "usa:A130_Super_Hellcat":                            'S.Hellc',
    "usa:A132_T77":                                      'T77',
    "usa:A134_M24E2_SuperChaffee":                       'S.Chaff',
    "usa:A136_T42":                                      'T42',
    "usa:A139_M_III_Y":                                  'M-III',
    "usa:A13_T34_hvy":                                   'T34',
    "usa:A13_T34_hvy_BF":                                'T34bf',
    "usa:A13_T34_hvy_FL":                                'T34',
    "usa:A13_T34_hvy_IGR":                               'T34',
    "usa:A140_ASTRON_REX_105mm":                         'astron',
    "usa:A141_M_IV_Y":                                   'M-IV',
    "usa:A141_M_IV_Y_MT_BF":                             'Noir',
    "usa:A142_Pawlack_Tank":                             'Pawlack',
    "usa:A143_M_V_Y":                                    'M-V',
    "usa:A144_M_VI_Y":                                   'M-VI',
    "usa:A145_TS_54":                                    'TS·54',
    "usa:A146_TL_7_120":                                 'TL-7',
    "usa:A147_M_II_Y":                                   'M-II',
    "usa:A148_Convertible_Medium_Tank_T3":               'T3·C',
    "usa:A149_AMBT":                                     'ambt',
    "usa:A14_T30":                                       'T30',
    "usa:A14_T30_FL":                                    'T30',
    "usa:A150_MBT_B":                                    'mbt·b',
    "usa:A151_TS_60":                                    'ts·60',
    "usa:A152_M_Project_2":                              'Improv',
    "usa:A152_M_Project":                                'Improv',
    "usa:A153_XM66F":                                    'XM66F',
    "usa:A154_Convertible_Medium_Tank_T3E2":             'T3E2·C',
    "usa:A156_T54_2022":                                 'T54·2022',
    "usa:A158_T832":                                     'T832',
    "usa:A15_T57":                                       'T57',
    "usa:A160_M24_594":                                  'M24/594',
    "usa:A161_ARMT":                                     'ARMT',
    "usa:A169_PattonIII_120":                            'PattonT',
    "usa:A16_M7_Priest":                                 'Prist',
    "usa:A17_M37":                                       'M37',
    "usa:A18_M41":                                       'M41',
    "usa:A19_T2_lt":                                     'T2lt',
    "usa:A21_T14":                                       'T14',
    "usa:A21_T14_MapsTraining_Player_HT_1":              'T14',
    "usa:A22_M5_Stuart":                                 'M5stu',
    # "usa:A22_M5_Stuart_bootcamp":                        'M5stu',
    "usa:A23_M7_med":                                    'M7',
    "usa:A24_T2_med":                                    'T2med',
    # "usa:A24_T2_med_bot":                                'T2med',
    "usa:A25_M2_med":                                    'M2med',
    # "usa:A25_M2_med_bootcamp":                           'M2med',
    "usa:A26_T18":                                       'T18',
    "usa:A27_T82":                                       'T82hmc',
    "usa:A29_T40":                                       'T40',
    "usa:A30_M10_Wolverine":                             'Wolvr',
    "usa:A31_M36_Slagger":                               'Jacks',
    "usa:A32_M12":                                       'M12',
    "usa:A33_MTLS-1G14":                                 'mtls',
    "usa:A34_M24_Chaffee":                               'Chaff',
    "usa:A35_Pershing":                                  'Persh',
    "usa:A35_Pershing_IGR":                              'Persh',
    "usa:A36_Sherman_Jumbo":                             'Jumbo',
    "usa:A36_Sherman_Jumbo_IGR":                         'Jumbo',
    "usa:A36_Sherman_Jumbo_bootcamp":                    'Jumbo',
    "usa:A37_M40M43":                                    'M40·43',
    "usa:A38_T92":                                       'T92',
    "usa:A39_T28":                                       'T28',
    "usa:A40_T95":                                       'T95',
    "usa:A41_M18_Hellcat":                               'Hellc',
    "usa:A43_M22_Locust":                                'Locst',
    "usa:A44_M4A2E4":                                    'M4a2e4',
    "usa:A45_M6A2E1":                                    'M6a2e1',
    "usa:A46_T3":                                        'T3hmc',
    "usa:A57_M8A1":                                      'M8a1',
    "usa:A58_T67":                                       'T67',
    "usa:A58_T67_IGR":                                   'T67',
    "usa:A62_Ram-II":                                    'Ram2',
    "usa:A63_M46_Patton":                                'M46Pt',
    "usa:A63_M46_Patton_FL":                             'M46Pt·fl',
    "usa:A63_M46_Patton_KR":                             'M46PtKR',
    "usa:A64_T25_AT":                                    'T25at',
    "usa:A64_T25_AT_FL":                                 'T25at',
    "usa:A66_M103":                                      'M103',
    "usa:A67_T57_58":                                    'T57hv',
    "usa:A68_T28_Prototype":                             'T28Pr',
    "usa:A69_T110E5":                                    '110e5',
    "usa:A69_T110E5_cl":                                 'T110E5cl',
    "usa:A69_T110E5_7x7":                                'T110E5',
    "usa:A71_T21":                                       'T21',
    "usa:A71_T21_MapsTraining_Dummy_LT_2":               'T21',
    "usa:A72_T25_2":                                     'T25/2',
    "usa:A72_T25_2_SH":                                  'raven',
    "usa:A74_T1_E6":                                     'T1e6',
    "usa:A78_M4_Improved":                               'M4·Imp',
    "usa:A80_T26_E4_SuperPershing":                      'T26e4',
    "usa:A80_T26_E4_SuperPershing_FL":                   'T26e4',
    "usa:A81_T95_E2":                                    'T95e2',
    "usa:A83_T110E4":                                    '110e4',
    "usa:A83_T110E4_7x7":                                '110e4',
    "usa:A85_T110E3":                                    '110e3',
    "usa:A86_T23E3":                                     'T23e3',
    "usa:A87_M44":                                       'M44',
    "usa:A88_M53_55":                                    'M53·55',
    "usa:A89_T54E1":                                     '54E1',
    "usa:A90_T69":                                       'T69',
    "usa:A90_T69_IGR":                                   'T69',
    "usa:A92_M60":                                       'M60',
    "usa:A93_T7_Combat_Car":                             'T7·CC',
    "usa:A94_T37":                                       'T37',
    "usa:A95_T95_E6":                                    'T95e6',
    "usa:A97_M41_Bulldog":                               'Buldog',
    "usa:A97_M41_Bulldog_FL":                            'Buldog',
    "usa:A99_T92_LT":                                    't92lt',
    "ussr:Observer":                                     '',
    "ussr:R01_IS":                                       'Is',
    "ussr:R02_SU-85":                                    'Su85',
    "ussr:R03_BT-7":                                     'Bt7',
  # "ussr:R03_BT-7_bootcamp":                            'Bt7',
    "ussr:R04_T-34":                                     't34',
    "ussr:R04_T-34_MapsTraining_Player_MT_1":            't34',
    "ussr:R05_KV":                                       'KV',
    "ussr:R06_T-28":                                     't28',
  # "ussr:R06_T-28_bootcamp":                            't28',
    "ussr:R07_T-34-85":                                  't34·85',
  # "ussr:R07_T-34-85_bootcamp":                         't34·85',
    "ussr:R08_BT-2":                                     'Bt2',
    # "ussr:R08_BT-2_bootcamp":                            'Bt2',
    "ussr:R09_T-26":                                     't26',
    # "ussr:R09_T-26_bot":                                 't26',
    "ussr:R1008_T34_85M_NewOnBoarding":                  't34·85m',
    "ussr:R100_SU122A":                                  'Su122',
    "ussr:R101_MT25":                                    'Mt·25',
    "ussr:R104_Object_430_II":                           'Ob.430v2',
    "ussr:R105_BT_7A":                                   'Bt7a',
    "ussr:R106_KV85":                                    'Kv·85',
    "ussr:R106_KV85_IGR":                                'Kv·85',
    "ussr:R107_LTB":                                     'LTB',
    "ussr:R108_T34_85M":                                 't34·85m',
    "ussr:R109_T54S":                                    't54obl',
    "ussr:R10_AT-1":                                     'At1',
    "ussr:R110_Object_260":                              'Ob.260',
    "ussr:R111_ISU130":                                  'isu130',
    "ussr:R112_T54_45":                                  't54obr1',
    "ussr:R112_T54_45_FL":                               't54obr1·fl',
    "ussr:R113_Object_730":                              'Is·5',
    "ussr:R114_Object_244":                              'Ob.244',
    "ussr:R115_IS-3_auto":                               'Is·3mz',
    "ussr:R115_IS-3_auto_S":                             'Is·3mz·S',
    "ussr:R115_IS-3_auto_test":                          'Is·3mz·T',
    "ussr:R116_ISU122C_Berlin":                          'isu122c',
    "ussr:R117_T34_85_Rudy":                             'Rudy',
    "ussr:R118_T28_F30":                                 't28f30',
    "ussr:R119_Object_777":                              'Ob.777',
    "ussr:R119_Object_777C":                             'Ob.777c',
    "ussr:R11_MS-1":                                     'Ms·1',
    # "ussr:R11_MS-1_bot":                                 'Ms·1',
    "ussr:R120_T22SR_A22":                               't22sr',
    "ussr:R121_KV4_KTT":                                 'Kv·4ktts',
    "ussr:R122_T44_100":                                 't44·100',
    "ussr:R122_T44_100B":                                't44·100m',
    "ussr:R123_Kirovets_1":                              'Kirov1',
    "ussr:R125_T_45":                                    't45',
    "ussr:R126_Object_730_5":                            'Ob.268v5',
    "ussr:R127_T44_100_I":                               't44·100I',
    "ussr:R127_T44_100_K":                               't44·100K',
    "ussr:R127_T44_100_M":                               't44·100M',
    "ussr:R127_T44_100_P":                               't44·100P',
    "ussr:R127_T44_100_U":                               't44·100U',
    "ussr:R128_KV4_Kreslavskiy":                         'Kv·4·Kresl',
    "ussr:R129_Object_257":                              'Ob.257p',
    "ussr:R12_A-20":                                     'A·20',
    "ussr:R131_Tank_Gavalov":                            'ltg',
    "ussr:R132_VNII_100LT":                              't100lt',
    "ussr:R133_KV_122":                                  'Kv122',
    "ussr:R134_Object_252K":                             'zashch',
    "ussr:R134_Object_252U":                             'Ob.252u',
    "ussr:R135_T_103":                                   't103',
    "ussr:R139_IS_M":                                    'Is·M',
    "ussr:R13_KV-1s":                                    'Kv·1s',
    "ussr:R140_M4_Loza":                                 'M4·Lo',
    "ussr:R143_T_29":                                    't·29',
    "ussr:R144_K_91":                                    'k91',
    "ussr:R145_Object_705_A":                            'Ob.705a',
    "ussr:R146_STG":                                     'stg',
    "ussr:R146_STG_Tday":                                'gvard',
    "ussr:R148_Object_430_U":                            'Ob.430u',
    "ussr:R149_Object_268_4":                            'Ob.268/4',
    "ussr:R14_SU-5":                                     'Su·5',
    "ussr:R14_SU-5_MapsTraining_Dummy_SPG_1":            'Su·5',
    "ussr:R151_Object_257_2":                            'Ob.257',
    "ussr:R152_KV2_W":                                   'Kv·2p',
    "ussr:R153_Object_705":                              'Ob.705',
    "ussr:R154_T_34E_1943":                              't34·s',
    "ussr:R155_Object_277":                              'Ob.777',
    "ussr:R156_IS_2M":                                   'Is·2M',
    "ussr:R157_Object_279R":                             'Ob.279R',
    "ussr:R158_LT_432":                                  'lt432',
    "ussr:R159_SU_130PM":                                'Su130pm',
    "ussr:R159_SU_130PM_DR":                             'Su130pm',
    "ussr:R15_S-51":                                     'S·51',
    "ussr:R160_T_50_2":                                  't50·2',
    "ussr:R161_T_116":                                   't116',
    "ussr:R165_Object_703_II":                           'Ob.703·122',
    "ussr:R165_Object_703_II_2":                         'Ob.703·100',
    "ussr:R169_ST_II":                                   'ST·II',
    "ussr:R16_SU-18":                                    'Su·18',
    "ussr:R170_IS_2_II":                                 'Is·2·II',
    "ussr:R171_IS_3_II":                                 'Is·3·II',
    "ussr:R172_Object_752":                              'Ob.752',
    "ussr:R173_K_91_2":                                  'k91·2',
    "ussr:R173_K_91_2_122":                              'k91·122',
    "ussr:R174_BT-5":                                    'Bt5',
    "ussr:R175_IS_2_screen":                             'Is·2·s',
    "ussr:R177_ISU_152K_BL10":                           'ISU·K',
    "ussr:R178_Object_780":                              'Ob.780',
    "ussr:R17_SU-100":                                   'Su100',
    "ussr:R180_Object_274_A":                            'Ob.274a',
    "ussr:R180_Object_274_A_MT_BF":                      'Ворон',
    "ussr:R183_K_91_PT":                                 'k91·PT',
    "ussr:R185_T_34_L_11_1941":                          't34·1941',
    "ussr:R186_KV_1_Screened":                           'Kv·1s',
    "ussr:R187_Object_590":                              'Ob.590',
    "ussr:R188_Object_259A":                             'Ob.259a',
    "ussr:R188_Object_259A_CN":                          'Ob.259a',
    "ussr:R18_SU-152":                                   'Su152',
    "ussr:R18_SU-152_IGR":                               'Su152',
    "ussr:R191_Object_283":                              'Ob.283',
    "ussr:R192_K_2":                                     'K·2',
    "ussr:R193_M4A2_T_34":                               'М4·85',
    "ussr:R194_ST_62_var_2":                             'St·62·II',
    "ussr:R195_T34M_54":                                 't34m-54',
    "ussr:R196_Object_452K":                             'Ob.452К',
    "ussr:R197_KV_1S_MZ":                                'Kv·1s·MZ',
    "ussr:R198_LTS_85":                                  'LTS·85',
    "ussr:R199_SU_122V":                                 'Su122В',
    "ussr:R19_IS-3":                                     'Is·3',
    "ussr:R19_IS-3_IGR":                                 'Is·3',
    "ussr:R200_KV_4_Turchaninov":                        'Kv-4t',
    "ussr:R201_IT_3":                                    'IT-3',
    "ussr:R202_SU_2_122":                                'Su2·122',
    "ussr:R204_ISU_122_2":                               'isu122',
    "ussr:R205_Tank_Rozanova":                           'Rozanov',
    "ussr:R205_Tank_Rozanova_Obsidian":                  'Obsidian',
    "ussr:R207_HT_130":                                  'Ht·130',
    "ussr:R208_Object_156O":                             'Ob.1560',
    "ussr:R20_T-44":                                     't44',
    "ussr:R20_T-44_FL":                                  't44',
    "ussr:R20_T-44_IGR":                                 't44',
    "ussr:R211_Object_261_4":                            'Ob.261/4',
    "ussr:R211_Object_261_5":                            'Ob.261/5',
    "ussr:R219_Waffentrager_E100_Gold":                  'WT100G',
    "ussr:R22_T-46":                                     't46',
    # "ussr:R22_T-46_bootcamp":                            't46',
    "ussr:R23_T-43":                                     't43',
    "ussr:R23_T-43_FL":                                  't43',
    "ussr:R23_T-43_MapsTraining_Player_MT_2":            't43',
    "ussr:R24_SU-76":                                    'Su76',
    "ussr:R25_GAZ-74b":                                  'Su85b',
    "ussr:R26_SU-8":                                     'Su·8',
    "ussr:R27_SU-14":                                    'Su·14',
    "ussr:R31_Valentine_LL":                             'Valnt',
    "ussr:R31_Valentine_LL_IGR":                         'Valnt',
    "ussr:R32_Matilda_II_LL":                            'Matil4',
    "ussr:R33_Churchill_LL":                             'Chrch3',
    "ussr:R34_BT-SV":                                    'BtSV',
    "ussr:R38_KV-220":                                   'Kv220',
    "ussr:R38_KV-220_beta":                              'Kv220·2t',
    "ussr:R39_KV-3":                                     'Kv·3',
    "ussr:R40_T-54":                                     't54',
    "ussr:R40_T-54_FL":                                  't54·fl',
    "ussr:R41_T-50":                                     't50',
    "ussr:R42_T-60":                                     't60',
    "ussr:R43_T-70":                                     't70',
    # "ussr:R43_T-70_bootcamp":                            't70',
    "ussr:R44_T80":                                      't80',
    "ussr:R44_T80_MapsTraining_Dummy_LT_1":              't80',
    "ussr:R45_IS-7":                                     'Is·7',
    "ussr:R45_IS-7_IGR":                                 'Is·7',
    "ussr:R45_IS-7_fallout":                             'Is·7',
    "ussr:R46_KV-13":                                    'Kv·13',
    "ussr:R46_KV-13_SH":                                 'varag',
    "ussr:R47_ISU-152":                                  'ISU',
    "ussr:R47_ISU-152_IGR":                              'ISU',
    "ussr:R49_SU100Y":                                   'Su100y',
    "ussr:R50_SU76I":                                    'Su76i',
    # "ussr:R50_SU76I_bootcamp":                           'Su76i',
    "ussr:R51_Object_212":                               'Ob.212',
    "ussr:R52_Object_261":                               'Ob.261',
    "ussr:R53_Object_704":                               'Ob.704',
    "ussr:R54_KV-5":                                     'Kv·5',
    "ussr:R54_KV-5_IGR":                                 'Kv·5',
    "ussr:R56_T-127":                                    't127',
    "ussr:R57_A43":                                      'A·43',
    "ussr:R58_SU-101":                                   'Su101',
    "ussr:R59_A44":                                      'A·44',
    "ussr:R60_Object416":                                'Ob.416',
    "ussr:R61_Object252":                                'Is·6',
    "ussr:R61_Object252_BF":                             'Is·6bf',
    "ussr:R61_Object252_FL":                             'Is·6·fl',
    "ussr:R63_ST_I":                                     'St·I',
    "ussr:R66_SU-26":                                    'Su·26',
    "ussr:R67_M3_LL":                                    'M3lght',
    "ussr:R68_A-32":                                     'A·32',
    "ussr:R70_T_50_2":                                   '50·2',
    "ussr:R71_IS_2B":                                    'Is·2B',
    "ussr:R72_T150":                                     't150',
    "ussr:R72_T150_MapsTraining_Dummy_HT_2":             't150',
    "ussr:R73_KV4":                                      'Kv·4',
    "ussr:R74_SU100M1":                                  'Su100m',
    "ussr:R75_SU122_54":                                 '122·54',
    "ussr:R77_KV2":                                      'Kv·2',
    "ussr:R77_KV2_IGR":                                  'Kv·2',
    "ussr:R78_SU_85I":                                   'Su85i',
    "ussr:R80_KV1":                                      'Kv1',
    "ussr:R81_IS8":                                      'T·10',
    "ussr:R84_Tetrarch_LL":                              'Tetrh',
    "ussr:R86_LTP":                                      'Ltp',
    # "ussr:R86_LTP_bootcamp":                             'Ltp',
    "ussr:R87_T62A":                                     't62a',
    "ussr:R87_T62A_fallout":                             't62a',
    "ussr:R88_Object268":                                'Ob.268',
    "ussr:R89_SU122_44":                                 '122·44',
    "ussr:R90_IS_4M":                                    'Is·4',
    "ussr:R90_IS_4M_7x7":                                'Is·4m',
    "ussr:R91_SU14_1":                                   'Su14·1',
    "ussr:R93_Object263":                                'Ob.263',
    "ussr:R93_Object263B":                               'Ob.263b',
    "ussr:R95_Object_907":                               'Ob.907',
    "ussr:R95_Object_907A":                              'Ob.907a',
    "ussr:R96_Object_430":                               'Ob.430',
    "ussr:R96_Object_430B":                              'Ob.430b',
    "ussr:R97_Object_140":                               'Ob.140',
    "ussr:R97_Object_140_cl":                            'Ob.140cl',
    "ussr:R98_T44_85":                                   't44·85',
    "ussr:R98_T44_85M":                                  't44·85m',
    "ussr:R99_T44_122":                                  't44·122',
    "ussr:R99_T44_122_CN":                               't44·122'
}
